require 'fastlane/action'
require 'json'
require 'fastlane_core/ui/ui'

module Fastlane
  module Helper
    class IosCdHelper
      # Define method to delete temporary keychain
      def delete_temp_keychain(name)
        if File.exist?(File.expand_path("~/Library/Keychains/#{name}-db"))
          Fastlane::Actions.delete_keychain(
            name: name
          )
        end
      end

      # Define method to create temporary keychain
      def create_temp_keychain(name, password)
        Fastlane::Actions.create_keychain(
          name: name,
          password: password,
          unlock: false,
          timeout: 0
        )
      end

      # Define method to ensure that temporary keychain exists
      def ensure_temp_keychain(name, password)
        delete_temp_keychain(name)
        create_temp_keychain(name, password)
      end

      # Check if a parameter is set or not
      def self.is_set(variable)
        str_variable = variable
        str_variable = variable.strip if variable.class.to_s == "String"
        variable && !(str_variable.nil? || str_variable.empty?)
      end

      # Decrypts ios credentials
      def self.decrypt_ios_keys(ios_directory)
        # Define the GPG command with options
        gpg_command = "gpg --quiet --batch --yes --decrypt --passphrase=#{ENV['IOS_KEYS_SECRET_PASSPHRASE']} \
          --output #{ios_directory}/ios_keys.zip #{ios_directory}/ios_keys.zip.gpg"

        # Execute the GPG command using system
        system(gpg_command)

        # Check if the command executed successfully
        if $?.success?

          # Move the extracted files to the current directory
          `jar xvf #{ios_directory} && mv #{ios_directory}/ios_keys/* #{ios_directory}`
        else
          puts("Erreur lors de la décompression du fichier GPG")
        end
      end

      # Parse credential file
      def parseIosCredentials(ios_directory)
        if File.exists?("#{ios_directory}/ios_crendentials.json")
          # Read file and decrypt it
          file = File.read("#{ios_directory}/ios_crendentials.json")
          JSON.parse(file)

        else 
          UI.error("❌ Ios credentials doesn't exist")
          puts("json file doesn't exist")
      end
    end
  end
end
